# mnemon-mcp

**Mnemon MCP Server Client**

MCP (Model Context Protocol) client for connecting AI models to Mnemon Knowledge Infrastructure.

This package is under active development. Stay tuned.

- GitHub: https://github.com/mnemon-ai
- X: https://x.com/mnemon_ai
